import * as schemas from '.';
/**
 * Create a sign request
 *
 * A request to create a sign request object
 */
export interface SignRequestCreateRequest {
    /**
     * Indicates if the sender should receive a `prepare_url` in the response to complete document preparation via UI.
     * Example: true
     */
    is_document_preparation_needed?: boolean;
    /**
     * Disables the usage of signatures generated by typing (text)
     * Example: true
     * @default true
     */
    are_text_signatures_enabled?: boolean;
    /**
     * Subject of sign request email. This is cleaned by sign request. If this field is not passed, a default subject will be used.
     * Example: Sign Request from Acme
     */
    email_subject?: string;
    /**
     * Message to include in sign request email. The field is cleaned through sanitization of specific characters. However, some html tags are allowed. Links included in the message are also converted to hyperlinks in the email. The message may contain the following html tags including `a`, `abbr`, `acronym`, `b`, `blockquote`, `code`, `em`, `i`, `ul`, `li`, `ol`, and `strong`. Be aware that when the text to html ratio is too high, the email may end up in spam filters. Custom styles on these tags are not allowed. If this field is not passed, a default message will be used.
     * Example: Hello! Please sign the document below
     */
    email_message?: string;
    /**
     * Reminds signers to sign a document on day 3, 8, 13 and 18. Reminders are only sent to outstanding signers.
     * Example: true
     */
    are_reminders_enabled?: boolean;
    /**
     * Array of signers for the sign request. 35 is the max number of signers permitted.
     */
    signers: schemas.SignRequestCreateSigner[];
    /**
     * List of files to create a signing document from. This is currently limited to one file. Only the ID and type fields are required for each file.
     */
    source_files: schemas.FileMini[];
    /**
     * The destination folder to place final, signed document and signing
     * log. Only `ID` and `type` fields are required. The root folder,
     * folder ID `0`, cannot be used.
     */
    parent_folder: schemas.FolderMini;
    /**
     * When a document contains sign related tags in the content, you can prefill them using this `prefill_tags` by referencing the 'id' of the tag as the `external_id` field of the prefill tag.
     */
    prefill_tags?: schemas.SignRequestPrefillTag[];
    /**
     * Number of days after which this request will automatically expire if not completed
     * Example: 2
     */
    days_valid?: number;
    /**
     * This can be used to reference an ID in an external system that the sign request is related to.
     * Example: 123
     */
    external_id?: string;
}
